.. opentiva documentation master file, created by
   sphinx-quickstart on Sun Mar 21 05:42:36 2021.

Welcome to opentiva's documentation!
====================================

opentiva is a free and open-source python module that simulates target
controlled infusions by using mathematical models relating to the
pharmacokinetic and pharmacodynamic compartment models of drugs used in
anaesthetic practice.


Contents
--------

.. toctree::
   :maxdepth: 1

   source/install.rst
   source/background.rst
   source/userguide.rst
   source/advanced.rst
   source/models.rst
   API reference <source/opentiva.rst>

Features
--------

- Plasma and effect site targeting
- One, two and three compartment modelling
- Built in Pk/Pd models from a range of drugs
- Tpeak :math:`k_{e0}` calcuation
- User defined infusions
- Optional k20 elimination in two compartment modelling
- Customize a range of properties relating to the targetting and maintenance
  methods

Installation
------------

Install `opentiva` by running:

    pip install opentiva

Contribute
----------

- Issue Tracker: github.com/opentiva/opentiva/issues
- Source Code: github.com/opentiva/opentiva

Support
-------

If you are having issues, please let us know via github or
opentiva@jpselby.co.uk.

Donate
------

Support opentiva by donating to:

- `Buy me a coffee <https://www.buymeacoffee.com/opentiva>`_
- BTC bc1qfxtg5fl900fu000hc5j0yajs9d958s0tcwz6vh
- ETH 0xeDf7C1fA7b0Ed483e9DA563d05bE58B7fcD57f16

Disclaimer
----------

opentiva is for informational, research and educational purposes only.
The pharmacokinetic/ pharmacodynamics are all obtained from medical
literature and infusions resulting from these can vary widely.
The user assumes all risks from the use of this application for clinical
purposes.

License
-------

The project is licensed under the MIT license.

